@@ -37,14 +37,14 @@ int loc_network_new_from_string(struct loc_ctx* ctx, struct loc_network** networ
 		const char* address_string);
 struct loc_network* loc_network_ref(struct loc_network* network);
 struct loc_network* loc_network_unref(struct loc_network* network);
-char* loc_network_str(struct loc_network* network);
+const char* loc_network_str(struct loc_network* network);
 int loc_network_address_family(struct loc_network* network);
 unsigned int loc_network_prefix(struct loc_network* network);
 
 const struct in6_addr* loc_network_get_first_address(struct loc_network* network);
-char* loc_network_format_first_address(struct loc_network* network);
+const char* loc_network_format_first_address(struct loc_network* network);
 const struct in6_addr* loc_network_get_last_address(struct loc_network* network);
-char* loc_network_format_last_address(struct loc_network* network);
+const char* loc_network_format_last_address(struct loc_network* network);
 int loc_network_matches_address(struct loc_network* network, const struct in6_addr* address);
 
 const char* loc_network_get_country_code(struct loc_network* network);
@@ -68,55 +68,6 @@ struct loc_network_list* loc_network_exclude_list(
 
 #ifdef LIBLOC_PRIVATE
 
-static inline struct in6_addr address_increment(const struct in6_addr* address) {
-	struct in6_addr a = *address;
-
-	for (int octet = 15; octet >= 0; octet--) {
-		if (a.s6_addr[octet] < 255) {
-			a.s6_addr[octet]++;
-			break;
-		} else {
-			a.s6_addr[octet] = 0;
-		}
-	}
-
-	return a;
-}
-
-static inline struct in6_addr address_decrement(const struct in6_addr* address) {
-	struct in6_addr a = *address;
-
-	for (int octet = 15; octet >= 0; octet--) {
-		if (a.s6_addr[octet] > 0) {
-			a.s6_addr[octet]--;
-			break;
-		}
-	}
-
-	return a;
-}
-
-static inline int loc_address_family(const struct in6_addr* address) {
-	if (IN6_IS_ADDR_V4MAPPED(address))
-		return AF_INET;
-	else
-		return AF_INET6;
-}
-
-static inline int loc_address_count_trailing_zero_bits(const struct in6_addr* address) {
-	int zeroes = 0;
-
-	for (int octet = 15; octet >= 0; octet--) {
-		if (address->s6_addr[octet]) {
-			zeroes += __builtin_ctz(address->s6_addr[octet]);
-			break;
-		} else
-			zeroes += 8;
-	}
-
-	return zeroes;
-}
-
 int loc_network_to_database_v1(struct loc_network* network, struct loc_database_network_v1* dbobj);
 int loc_network_new_from_database_v1(struct loc_ctx* ctx, struct loc_network** network,
 		struct in6_addr* address, unsigned int prefix, const struct loc_database_network_v1* dbobj);
