@@ -59,10 +59,8 @@ LOC_EXPORT int loc_network_new(struct loc_ctx* ctx, struct loc_network** network
 	}
 
 	struct loc_network* n = calloc(1, sizeof(*n));
-	if (!n) {
-		errno = ENOMEM;
+	if (!n)
 		return 1;
-	}
 
 	n->ctx = loc_ref(ctx);
 	n->refcount = 1;
@@ -118,9 +116,6 @@ static void loc_network_free(struct loc_network* network) {
 }
 
 LOC_EXPORT struct loc_network* loc_network_unref(struct loc_network* network) {
-	if (!network)
-		return NULL;
-
 	if (--network->refcount > 0)
 		return network;
 
@@ -580,7 +575,7 @@ int loc_network_new_from_database_v1(struct loc_ctx* ctx, struct loc_network** n
 
 	int r = loc_network_new(ctx, network, address, prefix);
 	if (r) {
-		ERROR(ctx, "Could not allocate a new network: %s", strerror(-r));
+		ERROR(ctx, "Could not allocate a new network: %m\n");
 		return r;
 	}
 
@@ -632,7 +627,7 @@ struct loc_network_tree_node {
 int loc_network_tree_new(struct loc_ctx* ctx, struct loc_network_tree** tree) {
 	struct loc_network_tree* t = calloc(1, sizeof(*t));
 	if (!t)
-		return -ENOMEM;
+		return 1;
 
 	t->ctx = loc_ref(ctx);
 	t->refcount = 1;
@@ -858,9 +853,6 @@ static void loc_network_tree_node_free(struct loc_network_tree_node* node) {
 }
 
 struct loc_network_tree_node* loc_network_tree_node_unref(struct loc_network_tree_node* node) {
-	if (!node)
-		return NULL;
-
 	if (--node->refcount > 0)
 		return node;
 
