@@ -16,8 +16,8 @@
 
 #include <Python.h>
 
-#include <loc/libloc.h>
-#include <loc/as.h>
+#include <libloc/libloc.h>
+#include <libloc/as.h>
 
 #include "locationmodule.h"
 #include "as.h"
